==> haskell-warp-3.3.30-52-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 warp
version:              3.3.30
visibility:           public
id:                   warp-3.3.30-DAHUlH7qmMW8GtlCwsSvsK
key:                  warp-3.3.30-DAHUlH7qmMW8GtlCwsSvsK
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  d10e7487dbe643f962cbf76be2613d0d
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP1
    Network.Wai.Handler.Warp.HTTP2 Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-9.2.8/site-local/warp-3.3.30
library-dirs:         /usr/lib/ghc-9.2.8/site-local/warp-3.3.30
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp
hs-libraries:         HSwarp-3.3.30-DAHUlH7qmMW8GtlCwsSvsK
depends:
    array-0.5.4.0 auto-update-0.1.6-5wV6PrgtFDOBQxx2gRZzYS
    base-4.16.4.0 bsb-http-chunked-0.0.0.4-5zpEP5pnWjq7fUiNR3Wb84
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-2Tjf2PFkxP43DkqVUMYCmf
    containers-0.6.5.1 crypton-x509-1.7.6-KbMZo8NHR0ZB59AJxC0rUM
    ghc-prim-0.8.0 hashable-1.4.3.0-7566tBsT9J8EFScR3Tb2Bc
    http-date-0.0.11-9IwamcJwgdC2b1hbg6kbEw
    http-types-0.12.4-B3znMwHTe3dL304Bd3IJgZ
    http2-4.1.0-FLjU7bccjsu2M0qkwgRRM0
    iproute-1.7.12-Fiey82fIX8U50eHtwqFDMu
    network-3.1.4.0-IeiVJWXSaeWHp5XfJw1SH3
    recv-0.1.0-1IBiPQ7ikGm4kyz562j3Cj
    simple-sendfile-0.2.32-D7WXbGUeJm2IcCxBrPDaqA stm-2.5.0.2
    streaming-commons-0.2.2.6-GB9r0d1CyyJLCe9Mlwe8Tn text-1.2.5.0
    time-manager-0.0.1-DvKtRULvkbQIXkz7yMdQxX unix-2.7.2.2
    unliftio-0.2.25.0-56sfjNmy7BWDzWuwznFqC8
    vault-0.3.1.5-KGmCdA93rcM4DaC6kTp3wh
    wai-3.2.4-JJVI15W7E9rGAtOPSLOeBU word8-0.1.3-Bbsc0ZijkBHAg5mnae6Bis

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-3.3.30-70-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 warp
version:              3.3.30
visibility:           public
id:                   warp-3.3.30-A59ReqdFC07LgOaV7Ls0Bk
key:                  warp-3.3.30-A59ReqdFC07LgOaV7Ls0Bk
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  d118d8c142cc3c7323aa607dfc69d614
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP1
    Network.Wai.Handler.Warp.HTTP2 Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-9.2.8/site-local/warp-3.3.30
library-dirs:         /usr/lib/ghc-9.2.8/site-local/warp-3.3.30
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp
hs-libraries:         HSwarp-3.3.30-A59ReqdFC07LgOaV7Ls0Bk
depends:
    array-0.5.4.0 auto-update-0.1.6-2vELbVwL9De2twxwyMaMtg
    base-4.16.4.0 bsb-http-chunked-0.0.0.4-1foFN4uMSOV5dAwlKX9ciA
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh
    containers-0.6.5.1 crypton-x509-1.7.6-AT1aSHFzIIlFru8iIljDNg
    ghc-prim-0.8.0 hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    http-date-0.0.11-E2fwJvbT2lF8g6FW0xlnls
    http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
    http2-4.1.0-GTQUgEMNBnQBOc7JeJHFxV
    iproute-1.7.12-5Hl7VCLvmHF2LaknTOyjlO
    network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ
    recv-0.1.0-Jz2IHauJ4L6z7BFkGp9S6
    simple-sendfile-0.2.32-DFTNlJ29FsrLYaNb7XwEm2 stm-2.5.0.2
    streaming-commons-0.2.2.6-BYBDcyumTobELXYn1pU9hC text-1.2.5.0
    time-manager-0.0.1-JO6rZ7N686wG4LbWdN5w9T unix-2.7.2.2
    unliftio-0.2.25.0-LM0KsdTS0NHVSVsirPxfP
    vault-0.3.1.5-1WZud07yl3a9ZcipFufCGQ
    wai-3.2.4-JIqkXCnMPAzFKNQzPpgW2q word8-0.1.3-Bbsc0ZijkBHAg5mnae6Bis

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
